==> mag_tools-0.2.193-py3-none-any.whl: mag_tools/utils/common/time_probe.py <==
import time
from datetime import datetime
from typing import List, Optional

from mag_tools.log.logger import Logger
from mag_tools.model.log_type import LogType
from mag_tools.utils.common.check_node import CheckNode
from model.time_unit import TimeUnit


class TimeProbe:
    def __init__(self, name: str):
        """
        初始化 TimeProbe 类的实例
        :param name: 探测器标题
        """
        self.__name = name
        self.__start_time = time.time_ns()  # 纳秒
        self.__previous_time = self.__start_time # 纳秒
        self.__check_nodes = [CheckNode(0, "初始节点", datetime.now(), 0, 0)]

    @classmethod
    def get_probe(cls, name: str = "性能监测"):
        """
        启动时间探测
        :param name: 探测器标题
        :return: TimeProbe 实例
        """
        return cls(name)

    def check(self, node_name: Optional[str] = None):
        """
        检测上次到当前检测点的时间差
        :param node_name: 节点名称
        :return: 当前节点信息
        """
        now_time = time.time_ns() # 当前时间，纳秒
        current_cost = now_time - self.__previous_time  # 纳秒
        total_cost = now_time - self.__start_time   # 纳秒

        node = CheckNode(len(self.__check_nodes), node_name, datetime.now(), current_cost, total_cost)
        self.__check_nodes.append(node)
        self.__previous_time = now_time
        return node

    @property
    def start_time(self):
        return datetime.fromtimestamp(self.__start_time // 1e9)

    def total_time(self, time_unit: TimeUnit = TimeUnit.NANOSECOND):
        """
        检测开始到这次检测点的时间差
        :return: 时间差，单位：纳秒
        """
        cost = time.time_ns() - self.__start_time
        if time_unit == TimeUnit.MICROSECOND:
            cost /= 1e3
        elif time_unit == TimeUnit.MILLISECOND:
            cost /= 1e6
        elif time_unit == TimeUnit.SECOND:
            cost /= 1e9
        elif time_unit == TimeUnit.MINUTE:
            cost /= 60 * 1e9
        elif time_unit == TimeUnit.HOUR:
            cost /= 3600 * 1e9
        elif time_unit == TimeUnit.DAY:
            cost /= 86400 * 1e9
        elif time_unit == TimeUnit.WEEK:
            cost /= 604800 * 1e9
        elif time_unit == TimeUnit.MONTH:
            cost /= 2592000 * 1e9
        elif time_unit == TimeUnit.YEAR:
            cost /= 31536000 * 1e9
        return cost

    def print(self, *args):
        """
        打印节点信息
        :param args: 格式化参数
        :return: 当前节点信息
        """
        title = self.__name.format(*args)
        node = self.check(title)
        Logger.info(LogType.PERFORMANCE, f"[{title}]:\n  {node.log()}")
        return node

    def write_log(self):
        """
        写入日志信息
        """
        message = ''
        for node in self.__check_nodes:
            message += f"[node]:\n{node.log()}\n"

        Logger.info(LogType.PERFORMANCE, f"{self.__name}\n{message}")

    def get_check_nodes(self) -> List[CheckNode]:
        """
        获取所有检测节点
        :return: 检测节点列表
        """
        return self.__check_nodes

==> mag_tools-0.2.195-py3-none-any.whl: mag_tools/utils/common/time_probe.py <==
import time
from datetime import datetime
from typing import List, Optional

from mag_tools.log.logger import Logger
from mag_tools.model.log_type import LogType
from mag_tools.utils.common.check_node import CheckNode
from mag_tools.model.time_unit import TimeUnit


class TimeProbe:
    def __init__(self, name: str):
        """
        初始化 TimeProbe 类的实例
        :param name: 探测器标题
        """
        self.__name = name
        self.__start_time = time.time_ns()  # 纳秒
        self.__previous_time = self.__start_time # 纳秒
        self.__check_nodes = [CheckNode(0, "初始节点", datetime.now(), 0, 0)]

    @classmethod
    def get_probe(cls, name: str = "性能监测"):
        """
        启动时间探测
        :param name: 探测器标题
        :return: TimeProbe 实例
        """
        return cls(name)

    def check(self, node_name: Optional[str] = None):
        """
        检测上次到当前检测点的时间差
        :param node_name: 节点名称
        :return: 当前节点信息
        """
        now_time = time.time_ns() # 当前时间，纳秒
        current_cost = now_time - self.__previous_time  # 纳秒
        total_cost = now_time - self.__start_time   # 纳秒

        node = CheckNode(len(self.__check_nodes), node_name, datetime.now(), current_cost, total_cost)
        self.__check_nodes.append(node)
        self.__previous_time = now_time
        return node

    @property
    def start_time(self):
        return datetime.fromtimestamp(self.__start_time // 1e9)

    def total_time(self, time_unit: TimeUnit = TimeUnit.MILLISECOND):
        """
        检测开始到这次检测点的时间差
        :return: 时间差，单位：纳秒
        """
        cost = time.time_ns() - self.__start_time
        if time_unit == TimeUnit.MICROSECOND:
            cost /= 1e3
        elif time_unit == TimeUnit.MILLISECOND:
            cost /= 1e6
        elif time_unit == TimeUnit.SECOND:
            cost /= 1e9
        elif time_unit == TimeUnit.MINUTE:
            cost /= 60 * 1e9
        elif time_unit == TimeUnit.HOUR:
            cost /= 3600 * 1e9
        elif time_unit == TimeUnit.DAY:
            cost /= 86400 * 1e9
        elif time_unit == TimeUnit.WEEK:
            cost /= 604800 * 1e9
        elif time_unit == TimeUnit.MONTH:
            cost /= 2592000 * 1e9
        elif time_unit == TimeUnit.YEAR:
            cost /= 31536000 * 1e9
        return cost

    def print(self, *args):
        """
        打印节点信息
        :param args: 格式化参数
        :return: 当前节点信息
        """
        title = self.__name.format(*args)
        node = self.check(title)
        Logger.info(LogType.PERFORMANCE, f"[{title}]:\n  {node.log()}")
        return node

    def write_log(self):
        """
        写入日志信息
        """
        message = ''
        for node in self.__check_nodes:
            message += f"[node]:\n{node.log()}\n"

        Logger.info(LogType.PERFORMANCE, f"{self.__name}\n{message}")

    def get_check_nodes(self) -> List[CheckNode]:
        """
        获取所有检测节点
        :return: 检测节点列表
        """
        return self.__check_nodes
